@@ -1,16 +1,9 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
-#![cfg_attr(feature = "fatal-warnings", deny(warnings))]
-
-use criterion::{criterion_group, criterion_main, Criterion};
+use criterion::{Criterion, criterion_group, criterion_main};
 use rpds::HashTrieMapSync;
 use std::hint::black_box;
 
 fn rpds_hash_trie_map_sync_insert(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
 
     c.bench_function("rpds hash trie map sync insert", move |b| {
         b.iter(|| {
@@ -21,12 +14,12 @@ fn rpds_hash_trie_map_sync_insert(c: &mut Criterion) {
             }
 
             map
-        })
+        });
     });
 }
 
 fn rpds_hash_trie_map_sync_insert_mut(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
 
     c.bench_function("rpds hash trie map sync insert mut", move |b| {
         b.iter(|| {
@@ -37,12 +30,12 @@ fn rpds_hash_trie_map_sync_insert_mut(c: &mut Criterion) {
             }
 
             map
-        })
+        });
     });
 }
 
 fn rpds_hash_trie_map_sync_remove(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
 
     c.bench_function("rpds hash trie map sync remove", move |b| {
         b.iter_with_setup(
@@ -67,7 +60,7 @@ fn rpds_hash_trie_map_sync_remove(c: &mut Criterion) {
 }
 
 fn rpds_hash_trie_map_sync_remove_mut(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
 
     c.bench_function("rpds hash trie map sync remove mut", move |b| {
         b.iter_with_setup(
@@ -92,7 +85,7 @@ fn rpds_hash_trie_map_sync_remove_mut(c: &mut Criterion) {
 }
 
 fn rpds_hash_trie_map_sync_get(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
     let mut map = HashTrieMapSync::new_sync();
 
     for i in 0..limit {
@@ -104,12 +97,12 @@ fn rpds_hash_trie_map_sync_get(c: &mut Criterion) {
             for i in 0..limit {
                 black_box(map.get(&i));
             }
-        })
+        });
     });
 }
 
 fn rpds_hash_trie_map_sync_iterate(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 1_000_000;
     let mut map = HashTrieMapSync::new_sync();
 
     for i in 0..limit {
@@ -121,10 +114,33 @@ fn rpds_hash_trie_map_sync_iterate(c: &mut Criterion) {
             for kv in map.iter() {
                 black_box(kv);
             }
-        })
+        });
     });
 }
 
+#[allow(unused_variables)]
+fn rpds_hash_trie_map_sync_iterate_parallel(c: &mut Criterion) {
+    #[cfg(feature = "rayon")]
+    {
+        use rayon::prelude::*;
+
+        let limit = 1_000_000;
+        let mut map = HashTrieMapSync::new_sync();
+
+        for i in 0..limit {
+            map.insert_mut(i, -(i as isize));
+        }
+
+        c.bench_function("rpds hash trie map sync iterate parallel", move |b| {
+            b.iter(|| {
+                map.par_iter().for_each(|kv| {
+                    black_box(kv);
+                });
+            });
+        });
+    }
+}
+
 criterion_group!(
     benches,
     rpds_hash_trie_map_sync_insert,
@@ -132,6 +148,7 @@ criterion_group!(
     rpds_hash_trie_map_sync_remove,
     rpds_hash_trie_map_sync_remove_mut,
     rpds_hash_trie_map_sync_get,
-    rpds_hash_trie_map_sync_iterate
+    rpds_hash_trie_map_sync_iterate,
+    rpds_hash_trie_map_sync_iterate_parallel
 );
 criterion_main!(benches);
