@@ -1,10 +1,3 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
-#![cfg_attr(feature = "fatal-warnings", deny(warnings))]
-
 use criterion::{Criterion, criterion_group, criterion_main};
 use rpds::Vector;
 use std::hint::black_box;
