@@ -1,16 +1,9 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
-#![cfg_attr(feature = "fatal-warnings", deny(warnings))]
-
-use criterion::{criterion_group, criterion_main, Criterion};
+use criterion::{Criterion, criterion_group, criterion_main};
 use rpds::VectorSync;
 use std::hint::black_box;
 
 fn rpds_vector_syncpush_back(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
 
     c.bench_function("rpds vector sync push back", move |b| {
         b.iter(|| {
@@ -21,12 +14,12 @@ fn rpds_vector_syncpush_back(c: &mut Criterion) {
             }
 
             vector
-        })
+        });
     });
 }
 
 fn rpds_vector_syncpush_back_mut(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
 
     c.bench_function("rpds vector sync push back mut", move |b| {
         b.iter(|| {
@@ -37,12 +30,12 @@ fn rpds_vector_syncpush_back_mut(c: &mut Criterion) {
             }
 
             vector
-        })
+        });
     });
 }
 
 fn rpds_vector_syncdrop_last(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
 
     c.bench_function("rpds vector sync drop last", move |b| {
         b.iter_with_setup(
@@ -67,7 +60,7 @@ fn rpds_vector_syncdrop_last(c: &mut Criterion) {
 }
 
 fn rpds_vector_syncdrop_last_mut(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 100_000;
 
     c.bench_function("rpds vector sync drop last mut", move |b| {
         b.iter_with_setup(
@@ -92,7 +85,7 @@ fn rpds_vector_syncdrop_last_mut(c: &mut Criterion) {
 }
 
 fn rpds_vector_syncget(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 1_000_000;
     let mut vector: VectorSync<usize> = VectorSync::new_sync();
 
     for i in 0..limit {
@@ -104,12 +97,13 @@ fn rpds_vector_syncget(c: &mut Criterion) {
             for i in 0..limit {
                 black_box(vector.get(i));
             }
-        })
+        });
     });
 }
 
+#[allow(clippy::explicit_iter_loop)]
 fn rpds_vector_synciterate(c: &mut Criterion) {
-    let limit = 10_000;
+    let limit = 1_000_000;
     let mut vector: VectorSync<usize> = VectorSync::new_sync();
 
     for i in 0..limit {
@@ -121,7 +115,7 @@ fn rpds_vector_synciterate(c: &mut Criterion) {
             for i in vector.iter() {
                 black_box(i);
             }
-        })
+        });
     });
 }
 
