@@ -1,31 +1,9 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
 #![cfg_attr(not(feature = "std"), no_std)]
-#![cfg_attr(feature = "fatal-warnings", deny(warnings))]
-#![deny(clippy::correctness)]
-#![warn(clippy::pedantic)]
-#![allow(clippy::match_bool)]
-#![allow(clippy::if_not_else)]
-#![allow(clippy::module_name_repetitions)]
-#![allow(clippy::similar_names)]
-#![allow(clippy::use_self)]
-#![allow(clippy::single_match_else)]
-#![allow(clippy::unnested_or_patterns)]
-#![allow(clippy::wildcard_imports)]
-#![allow(clippy::match_same_arms)]
-#![allow(clippy::missing_panics_doc)]
-#![allow(clippy::type_complexity)]
-#![allow(clippy::enum_glob_use)]
-// Note: If you change this remember to update `README.md`.  To do so run `./tools/update-readme.sh`.
-//! # Rust Persistent Data Structures
-//!
+// Note: If you change this remember to update `README.md`. To do so run `cargo rdme`.
 //! Rust Persistent Data Structures provides [fully persistent data structures](https://en.wikipedia.org/wiki/Persistent_data_structure)
 //! with structural sharing.
 //!
-//! ## Setup
+//! # Setup
 //!
 //! To use rpds add the following to your `Cargo.toml`:
 //!
@@ -34,7 +12,7 @@
 //! rpds = "<version>"
 //! ```
 //!
-//! ## Data structures
+//! # Data structures
 //!
 //! This crate offers the following data structures:
 //!
@@ -47,12 +25,12 @@
 //!   7. [`RedBlackTreeMap`](#redblacktreemap)
 //!   8. [`RedBlackTreeSet`](#redblacktreeset)
 //!
-//! ### `List`
+//! ## `List`
 //! [![List documentation](https://img.shields.io/badge/doc-List-303070.svg)](crate::list::List)
 //!
 //! Your classic functional list.
 //!
-//! #### Example
+//! ### Example
 //!
 //! ```rust
 //! use rpds::List;
@@ -70,14 +48,14 @@
 //! assert_eq!(list_dropped, list);
 //! ```
 //!
-//! ### `Vector`
+//! ## `Vector`
 //! [![`Vector` documentation](https://img.shields.io/badge/doc-Vector-303070.svg)](crate::vector::Vector)
 //!
-//! A sequence that can be indexed.  The implementation is described in
+//! A sequence that can be indexed. The implementation is described in
 //! [Understanding Persistent Vector Part 1](http://hypirion.com/musings/understanding-persistent-vector-pt-1)
 //! and [Understanding Persistent Vector Part 2](http://hypirion.com/musings/understanding-persistent-vector-pt-2).
 //!
-//! #### Example
+//! ### Example
 //!
 //! ```rust
 //! use rpds::Vector;
@@ -96,12 +74,12 @@
 //! assert_eq!(screaming_vector[2], "VECTOR!!!");
 //! ```
 //!
-//! ### `Stack`
+//! ## `Stack`
 //! [![`Stack` documentation](https://img.shields.io/badge/doc-Stack-303070.svg)](crate::stack::Stack)
 //!
-//! A LIFO (last in, first out) data structure.  This is just a [`List`](#list) in disguise.
+//! A LIFO (last in, first out) data structure. This is just a [`List`](#list) in disguise.
 //!
-//! #### Example
+//! ### Example
 //!
 //! ```rust
 //! use rpds::Stack;
@@ -119,12 +97,12 @@
 //! assert_eq!(stack_popped, stack);
 //! ```
 //!
-//! ### `Queue`
+//! ## `Queue`
 //! [![`Queue` documentation](https://img.shields.io/badge/doc-Queue-303070.svg)](crate::queue::Queue)
 //!
 //! A FIFO (first in, first out) data structure.
 //!
-//! #### Example
+//! ### Example
 //!
 //! ```rust
 //! use rpds::Queue;
@@ -141,14 +119,14 @@
 //! assert_eq!(queue_dequeued.peek(), Some(&"dois"));
 //! ```
 //!
-//! ### `HashTrieMap`
+//! ## `HashTrieMap`
 //! [![`HashTrieMap` documentation](https://img.shields.io/badge/doc-HashTrieMap-303070.svg)](crate::map::hash_trie_map::HashTrieMap)
 //!
 //! A map implemented with a [hash array mapped trie](https://en.wikipedia.org/wiki/Hash_array_mapped_trie).
 //! See [Ideal Hash Trees](https://infoscience.epfl.ch/record/64398/files/idealhashtrees.pdf) for
 //! details.
 //!
-//! #### Example
+//! ### Example
 //!
 //! ```rust
 //! use rpds::HashTrieMap;
@@ -170,12 +148,12 @@
 //! assert_eq!(map_pt_binary.get(&2), None);
 //! ```
 //!
-//! ### `HashTrieSet`
+//! ## `HashTrieSet`
 //! [![`HashTrieSet` documentation](https://img.shields.io/badge/doc-HashTrieSet-303070.svg)](crate::set::hash_trie_set::HashTrieSet)
 //!
 //! A set implemented with a [`HashTrieMap`](#hashtriemap).
 //!
-//! #### Example
+//! ### Example
 //!
 //! ```rust
 //! use rpds::HashTrieSet;
@@ -195,12 +173,12 @@
 //! assert!(!set_positive.contains(&"zero"));
 //! ```
 //!
-//! ### `RedBlackTreeMap`
+//! ## `RedBlackTreeMap`
 //! [![`RedBlackTreeMap` documentation](https://img.shields.io/badge/doc-RedBlackTreeMap-303070.svg)](crate::map::red_black_tree_map::RedBlackTreeMap)
 //!
 //! A map implemented with a [red-black tree](https://en.wikipedia.org/wiki/Red-Black_tree).
 //!
-//! #### Example
+//! ### Example
 //!
 //! ```rust
 //! use rpds::RedBlackTreeMap;
@@ -224,12 +202,12 @@
 //! assert_eq!(map_pt_binary.first(), Some((&0, &"zero")));
 //! ```
 //!
-//! ### `RedBlackTreeSet`
+//! ## `RedBlackTreeSet`
 //! [![`RedBlackTreeSet` documentation](https://img.shields.io/badge/doc-RedBlackTreeSet-303070.svg)](crate::set::red_black_tree_set::RedBlackTreeSet)
 //!
 //! A set implemented with a [`RedBlackTreeMap`](#redblacktreemap).
 //!
-//! #### Example
+//! ### Example
 //!
 //! ```rust
 //! use rpds::RedBlackTreeSet;
@@ -251,11 +229,11 @@
 //! assert_eq!(set_positive.first(), Some(&"one"));
 //! ```
 //!
-//! ## Other features
+//! # Other features
 //!
-//! ### Mutable methods
+//! ## Mutable methods
 //!
-//! When you change a data structure you often do not need its previous versions.  For those cases
+//! When you change a data structure you often do not need its previous versions. For those cases
 //! rpds offers you mutable methods which are generally faster:
 //!
 //! ```rust
@@ -270,7 +248,7 @@
 //! let set_0_1_2 = set.insert("two");
 //! ```
 //!
-//! ### Initialization macros
+//! ## Initialization macros
 //!
 //! There are convenient initialization macros for all data structures:
 //!
@@ -283,14 +261,14 @@
 //!
 //! Check the documentation for initialization macros of other data structures.
 //!
-//! ### Thread safety
+//! ## Thread safety
 //!
 //! All data structures in this crate can be shared between threads, but that is an opt-in ability.
-//! This is because there is a performance cost to make data structures thread safe.  That cost
+//! This is because there is a performance cost to make data structures thread safe. That cost
 //! is worth avoiding when you are not actually sharing them between threads.
 //!
 //! Of course if you try to share a rpds data structure across different threads you can count on
-//! the rust compiler to ensure that it is safe to do so.  If you are using the version of the data
+//! the rust compiler to ensure that it is safe to do so. If you are using the version of the data
 //! structure that is not thread safe you will get a compile-time error.
 //!
 //! To create a thread-safe version of any data structure use `new_sync()`:
@@ -310,16 +288,7 @@
 //! let vec = vector_sync!(42);
 //! ```
 //!
-//! ### `no_std` support
-//!
-//! This crate supports `no_std`.  To enable that you need to disable the default feature `std`:
-//!
-//! ```toml
-//! [dependencies]
-//! rpds = { version = "<version>", default-features = false }
-//! ```
-//!
-//! #### Further details
+//! ### Further details
 //!
 //! Internally the data structures in this crate maintain a lot of reference-counting pointers.
 //! These pointers are used both for links between the internal nodes of the data structure as well
@@ -327,15 +296,15 @@
 //!
 //! There are two implementations of reference-counting pointers in the standard library:
 //! [`Rc`](::alloc::rc::Rc) and
-//! [`Arc`](::alloc::sync::Arc).  They behave the same way, but
-//! `Arc` allows you to share the data it points to across multiple threads.  The downside is that
+//! [`Arc`](::alloc::sync::Arc). They behave the same way, but
+//! `Arc` allows you to share the data it points to across multiple threads. The downside is that
 //! it is significantly slower to clone and drop than `Rc`, and persistent data structures do a
 //! lot of those operations. In some microbenchmarks with rpds data structure we can see that
 //! using `Rc` instead of  `Arc` can make some operations twice as fast!  You can see this for
 //! yourself by running `cargo bench`.
 //!
 //! To implement this we parameterize the type of reference-counting pointer (`Rc` or `Arc`) as a
-//! type argument of the data structure.  We use the [archery](https://github.com/orium/archery/)
+//! type argument of the data structure. We use the [archery](https://github.com/orium/archery/)
 //! crate to do this in a convenient way.
 //!
 //! The pointer type can be parameterized like this:
@@ -343,21 +312,44 @@
 //! ```rust
 //! # use rpds::Vector;
 //! #
-//! let vec: Vector<u32, archery::ArcK> = Vector::new_with_ptr_kind();
+//! let vec: Vector<u32, archery::ArcTK> = Vector::new_with_ptr_kind();
 //! //                              ↖
 //! //                                This will use `Arc` pointers.
 //! //                                Change it to `archery::RcK` to use a `Rc` pointer.
 //! ```
 //!
-//! ### Serialization
+//! ## `no_std` support
 //!
-//! We support serialization through [serde](https://crates.io/crates/serde).  To use it
-//! enable the `serde` feature.  To do so change the rpds dependency in your `Cargo.toml` to
+//! This crate supports `no_std`. To enable that you need to disable the default feature `std`:
+//!
+//! ```toml
+//! [dependencies]
+//! rpds = { version = "<version>", default-features = false }
+//! ```
+//!
+//! ## Parallel iterator support
+//!
+//! [`HashTrieMap`](crate::map::hash_trie_map::HashTrieMap) supports parallel iterator with
+//! [rayon](https://crates.io/crates/rayon). To use them you need to enable the `rayon` feature.
+//!
+//! ## Serialization
+//!
+//! We support serialization through [serde](https://crates.io/crates/serde). To use it
+//! enable the `serde` feature. To do so change the rpds dependency in your `Cargo.toml` to
 //!
 //! ```toml
 //! [dependencies]
 //! rpds = { version = "<version>", features = ["serde"] }
 //! ```
+//!
+//! ## Bindings
+//!
+//! Bindings to use rpds from other programming languages exist. Below is a short list of those
+//! known to date.
+//!
+//! * [rpds.py](https://github.com/crate-py/rpds/) – Python
+//!
+//! Please feel free to send a pull request should you add support in a new language.
 
 extern crate alloc;
 
