@@ -1,23 +1,19 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
+#[cfg(feature = "rayon")]
+mod rayon;
 mod sparse_array_usize;
 
 use super::entry::Entry;
+use crate::List;
 use crate::list;
 use crate::utils::DefaultBuildHasher;
-use crate::List;
 use alloc::vec::Vec;
-use archery::{ArcK, RcK, SharedPointer, SharedPointerKind};
+use archery::{ArcTK, RcK, SharedPointer, SharedPointerKind};
 use core::borrow::Borrow;
 use core::fmt::Display;
 use core::hash::BuildHasher;
 use core::hash::Hash;
 use core::iter;
 use core::iter::FromIterator;
-use core::mem::size_of;
 use core::ops::Index;
 use core::slice;
 use sparse_array_usize::SparseArrayUsize;
@@ -26,12 +22,12 @@ type HashValue = u64;
 
 // TODO Use impl trait instead of this when available.
 pub type Iter<'a, K, V, P> =
-    core::iter::Map<IterPtr<'a, K, V, P>, fn(&'a SharedPointer<Entry<K, V>, P>) -> (&'a K, &'a V)>;
-pub type IterKeys<'a, K, V, P> = core::iter::Map<Iter<'a, K, V, P>, fn((&'a K, &V)) -> &'a K>;
-pub type IterValues<'a, K, V, P> = core::iter::Map<Iter<'a, K, V, P>, fn((&K, &'a V)) -> &'a V>;
+    iter::Map<IterPtr<'a, K, V, P>, fn(&'a SharedPointer<Entry<K, V>, P>) -> (&'a K, &'a V)>;
+pub type IterKeys<'a, K, V, P> = iter::Map<Iter<'a, K, V, P>, fn((&'a K, &V)) -> &'a K>;
+pub type IterValues<'a, K, V, P> = iter::Map<Iter<'a, K, V, P>, fn((&K, &'a V)) -> &'a V>;
 
 #[allow(clippy::cast_possible_truncation)]
-const DEFAULT_DEGREE: u8 = 8 * size_of::<usize>() as u8;
+const DEFAULT_DEGREE: u8 = usize::BITS as u8;
 
 /// Creates a [`HashTrieMap`](crate::HashTrieMap) containing the given arguments:
 ///
@@ -127,7 +123,7 @@ where
     hasher_builder: H,
 }
 
-pub type HashTrieMapSync<K, V, H = DefaultBuildHasher> = HashTrieMap<K, V, ArcK, H>;
+pub type HashTrieMapSync<K, V, H = DefaultBuildHasher> = HashTrieMap<K, V, ArcTK, H>;
 
 /// This map works like a trie that breaks the hash of the key in segments, and the segments are
 /// used as the index in the trie branches.
@@ -214,12 +210,11 @@ mod node_utils {
     use super::HashValue;
     use core::hash::BuildHasher;
     use core::hash::Hash;
-    use core::hash::Hasher;
     use core::mem::size_of_val;
 
-    // Returns the index of the array for the given hash on depth `depth`.
-    //
-    // When the hash is exhausted, meaning that we are at the maximum depth, this returns `None`.
+    /// Returns the index of the array for the given hash on depth `depth`.
+    ///
+    /// When the hash is exhausted, meaning that we are at the maximum depth, this returns `None`.
     #[inline]
     pub fn index_from_hash(hash: HashValue, depth: usize, degree: u8) -> Option<usize> {
         debug_assert!(degree.is_power_of_two());
@@ -238,11 +233,7 @@ mod node_utils {
     }
 
     pub fn hash<T: ?Sized + Hash, H: BuildHasher>(v: &T, hasher_builder: &H) -> HashValue {
-        let mut hasher = hasher_builder.build_hasher();
-
-        v.hash(&mut hasher);
-
-        hasher.finish()
+        hasher_builder.hash_one(v)
     }
 }
 
@@ -422,7 +413,7 @@ where
 
                                 self.compress();
                             }
-                        };
+                        }
 
                         removed
                     }
@@ -519,11 +510,9 @@ where
         Q: Hash + Eq,
     {
         match self {
-            Bucket::Single(entry) if entry.matches(key, key_hash) => Some(entry.borrow()),
+            Bucket::Single(entry) if entry.matches(key, key_hash) => Some(entry),
             Bucket::Single(_) => None,
-            Bucket::Collision(entries) => {
-                entries.iter().find(|e| e.matches(key, key_hash)).map(|e| e.borrow())
-            }
+            Bucket::Collision(entries) => entries.iter().find(|e| e.matches(key, key_hash)),
         }
     }
 
@@ -637,7 +626,7 @@ where
                                 *b = Bucket::Single(entry);
                             }
                             _ => (),
-                        };
+                        }
 
                         *bucket = Some(b);
 
@@ -853,6 +842,22 @@ where
         self.get(key).is_some()
     }
 
+    /// Test whether the two maps refer to the same content in memory.
+    ///
+    /// This would return true if you’re comparing a map to itself,
+    /// or if you’re comparing a map to a fresh clone of itself.
+    pub fn ptr_eq<PO: SharedPointerKind, HO: BuildHasher>(
+        &self,
+        other: &HashTrieMap<K, V, PO, HO>,
+    ) -> bool {
+        let a = SharedPointer::as_ptr(&self.root);
+        // Note how we're casting the raw pointer changing from P to PO
+        // We cannot perform the equality in a type safe way because the root type depends
+        // on P/PO, and we can't pass different types to SharedPtr::same_ptr or std::ptr::eq.
+        let b = SharedPointer::as_ptr(&other.root).cast::<Node<K, V, P>>();
+        core::ptr::eq(a, b)
+    }
+
     #[must_use]
     #[inline]
     pub fn size(&self) -> usize {
@@ -865,6 +870,7 @@ where
         self.size() == 0
     }
 
+    #[allow(clippy::iter_without_into_iter)]
     pub fn iter(&self) -> Iter<'_, K, V, P> {
         self.iter_ptr().map(|e| (&e.key, &e.value))
     }
@@ -904,7 +910,7 @@ where
     }
 }
 
-impl<'a, K, Q: ?Sized, V, P, H: BuildHasher> Index<&'a Q> for HashTrieMap<K, V, P, H>
+impl<K, Q: ?Sized, V, P, H: BuildHasher> Index<&Q> for HashTrieMap<K, V, P, H>
 where
     K: Eq + Hash + Borrow<Q>,
     Q: Hash + Eq,
@@ -954,8 +960,11 @@ where
     PO: SharedPointerKind,
 {
     fn eq(&self, other: &HashTrieMap<K, V, PO, H>) -> bool {
+        if self.ptr_eq(other) {
+            return true;
+        }
         self.size() == other.size()
-            && self.iter().all(|(key, value)| other.get(key).map_or(false, |v| *value == *v))
+            && self.iter().all(|(key, value)| other.get(key).is_some_and(|v| *value == *v))
     }
 }
 
@@ -1080,17 +1089,16 @@ where
 
 mod iter_utils {
     use super::HashValue;
-    use core::mem::size_of;
 
     pub fn trie_max_height(degree: u8) -> usize {
         let bits_per_level = (degree - 1).count_ones() as usize;
-        let hash_bits = 8 * size_of::<HashValue>();
+        let hash_bits = HashValue::BITS as usize;
 
-        (hash_bits / bits_per_level) + if hash_bits % bits_per_level > 0 { 1 } else { 0 }
+        (hash_bits / bits_per_level) + usize::from(hash_bits % bits_per_level > 0)
     }
 }
 
-impl<'a, K, V, P> IterPtr<'a, K, V, P>
+impl<K, V, P> IterPtr<'_, K, V, P>
 where
     K: Eq + Hash,
     P: SharedPointerKind,
@@ -1138,7 +1146,7 @@ where
     }
 }
 
-impl<'a, K: Eq + Hash, V, P> ExactSizeIterator for IterPtr<'a, K, V, P> where P: SharedPointerKind {}
+impl<K: Eq + Hash, V, P> ExactSizeIterator for IterPtr<'_, K, V, P> where P: SharedPointerKind {}
 
 #[cfg(feature = "serde")]
 pub mod serde {
