@@ -1,10 +1,5 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
 use super::entry::Entry;
-use archery::{ArcK, RcK, SharedPointer, SharedPointerKind};
+use archery::{ArcTK, RcK, SharedPointer, SharedPointerKind};
 use core::borrow::Borrow;
 use core::cmp::Ordering;
 use core::fmt::Display;
@@ -113,7 +108,7 @@ where
     size: usize,
 }
 
-pub type RedBlackTreeMapSync<K, V> = RedBlackTreeMap<K, V, ArcK>;
+pub type RedBlackTreeMapSync<K, V> = RedBlackTreeMap<K, V, ArcTK>;
 
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
 enum Color {
@@ -159,8 +154,8 @@ where
         Node { entry: SharedPointer::new(entry), color: Color::Black, left: None, right: None }
     }
 
-    fn borrow(node: &Option<SharedPointer<Node<K, V, P>, P>>) -> Option<&Node<K, V, P>> {
-        node.as_ref().map(|n| n.borrow())
+    fn borrow(node: Option<&SharedPointer<Node<K, V, P>, P>>) -> Option<&Node<K, V, P>> {
+        node.map(Borrow::borrow)
     }
 
     fn left_color(&self) -> Option<Color> {
@@ -270,9 +265,9 @@ where
     ///                  c   d
     /// ```
     fn balance(&mut self) {
-        use core::mem::swap;
         use Color::Black as B;
         use Color::Red as R;
+        use core::mem::swap;
 
         match self.color {
             B => {
@@ -542,7 +537,7 @@ where
                             }
                         }
                     }
-                };
+                }
 
                 true
             }
@@ -900,6 +895,23 @@ where
         self.get(key).is_some()
     }
 
+    /// Test whether the two maps refer to the same content in memory.
+    ///
+    /// This would return true if you’re comparing a map to itself,
+    /// or if you’re comparing a map to a fresh clone of itself.
+    pub fn ptr_eq<PO: SharedPointerKind>(&self, other: &RedBlackTreeMap<K, V, PO>) -> bool {
+        let a = self.root.as_ref().map_or(core::ptr::null(), SharedPointer::as_ptr);
+        // Note how we're casting the raw pointer changing from P to PO
+        // We cannot perform the equality in a type safe way because the root type depends
+        // on P/PO, and we can't pass different types to SharedPtr::same_ptr or std::ptr::eq.
+        let b = other
+            .root
+            .as_ref()
+            .map_or(core::ptr::null(), SharedPointer::as_ptr)
+            .cast::<Node<K, V, P>>();
+        core::ptr::eq(a, b)
+    }
+
     #[must_use]
     #[inline]
     pub fn size(&self) -> usize {
@@ -973,7 +985,7 @@ where
     }
 }
 
-impl<'a, K, Q: ?Sized, V, P> Index<&'a Q> for RedBlackTreeMap<K, V, P>
+impl<K, Q: ?Sized, V, P> Index<&Q> for RedBlackTreeMap<K, V, P>
 where
     K: Ord + Borrow<Q>,
     Q: Ord,
@@ -1013,8 +1025,11 @@ where
     PO: SharedPointerKind,
 {
     fn eq(&self, other: &RedBlackTreeMap<K, V, PO>) -> bool {
+        if self.ptr_eq(other) {
+            return true;
+        }
         self.size() == other.size()
-            && self.iter().all(|(key, value)| other.get(key).map_or(false, |v| *value == *v))
+            && self.iter().all(|(key, value)| other.get(key).is_some_and(|v| *value == *v))
     }
 }
 
@@ -1072,7 +1087,7 @@ where
 
         fmt.write_str("{")?;
 
-        for (k, v) in self.iter() {
+        for (k, v) in self {
             if !first {
                 fmt.write_str(", ")?;
             }
@@ -1121,7 +1136,6 @@ mod iter_utils {
     use alloc::vec::Vec;
     use archery::{SharedPointer, SharedPointerKind};
     use core::borrow::Borrow;
-    use core::mem::size_of;
     use core::ops::Bound;
 
     // This is a stack for navigating through the tree. It can be used to go either forwards or
@@ -1194,7 +1208,7 @@ mod iter_utils {
                 if !in_range {
                     self.stack.clear();
                 }
-            };
+            }
         }
 
         #[inline]
@@ -1202,19 +1216,19 @@ mod iter_utils {
             self.stack.last().map(|node| &node.entry)
         }
 
-        fn dig<Q>(&mut self, start_bound: Bound<&Q>, end_bound: Bound<&Q>)
+        fn dig<Q>(&mut self)
         where
             K: Borrow<Q>,
             Q: Ord + ?Sized,
         {
             let child = self.stack.last().and_then(|node| {
-                let c = if self.backwards { &node.right } else { &node.left };
+                let c = if self.backwards { node.right.as_ref() } else { node.left.as_ref() };
                 Node::borrow(c)
             });
 
             if let Some(c) = child {
                 self.stack.push(c);
-                self.dig(start_bound, end_bound);
+                self.dig();
             }
         }
 
@@ -1265,11 +1279,11 @@ mod iter_utils {
             Q: Ord + ?Sized,
         {
             if let Some(node) = self.stack.pop() {
-                let child = if self.backwards { &node.left } else { &node.right };
+                let child = if self.backwards { node.left.as_ref() } else { node.right.as_ref() };
 
                 if let Some(c) = Node::borrow(child) {
                     self.stack.push(c);
-                    self.dig(start_bound, end_bound);
+                    self.dig();
                 }
 
                 self.clear_if_finished(start_bound, end_bound);
@@ -1280,17 +1294,13 @@ mod iter_utils {
     pub fn lg_floor(size: usize) -> usize {
         debug_assert!(size > 0);
 
-        let c: usize = 8 * size_of::<usize>() - size.leading_zeros() as usize;
+        let c: usize = usize::BITS as usize - size.leading_zeros() as usize;
 
         c - 1
     }
 
     pub fn conservative_height(size: usize) -> usize {
-        if size > 0 {
-            2 * lg_floor(size + 1)
-        } else {
-            0
-        }
+        if size > 0 { 2 * lg_floor(size + 1) } else { 0 }
     }
 }
 
@@ -1305,7 +1315,7 @@ where
     size: usize,
 }
 
-impl<'a, K, V, P> IterPtr<'a, K, V, P>
+impl<K, V, P> IterPtr<'_, K, V, P>
 where
     K: Ord,
     P: SharedPointerKind,
@@ -1351,7 +1361,7 @@ where
     }
 }
 
-impl<'a, K: Ord, V, P> ExactSizeIterator for IterPtr<'a, K, V, P> where P: SharedPointerKind {}
+impl<K: Ord, V, P> ExactSizeIterator for IterPtr<'_, K, V, P> where P: SharedPointerKind {}
 
 #[derive(Debug)]
 pub struct RangeIterPtr<'a, K, V, RB, Q: ?Sized, P>
@@ -1374,7 +1384,7 @@ where
     RB: RangeBounds<Q>,
     P: SharedPointerKind,
 {
-    fn new(map: &'a RedBlackTreeMap<K, V, P>, range: RB) -> RangeIterPtr<'_, K, V, RB, Q, P> {
+    fn new(map: &'a RedBlackTreeMap<K, V, P>, range: RB) -> RangeIterPtr<'a, K, V, RB, Q, P> {
         RangeIterPtr { map, stack_forward: None, stack_backward: None, range, _q: PhantomData }
     }
 
