@@ -1,14 +1,10 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
-use crate::map::red_black_tree_map;
 use crate::RedBlackTreeMap;
-use archery::{ArcK, RcK, SharedPointerKind};
+use crate::map::red_black_tree_map;
+use archery::{ArcTK, RcK, SharedPointerKind};
 use core::borrow::Borrow;
 use core::cmp::Ordering;
 use core::fmt::Display;
+use core::hash::{Hash, Hasher};
 use core::iter::FromIterator;
 use core::ops::RangeBounds;
 
@@ -103,7 +99,7 @@ where
     map: RedBlackTreeMap<T, (), P>,
 }
 
-pub type RedBlackTreeSetSync<T> = RedBlackTreeSet<T, ArcK>;
+pub type RedBlackTreeSetSync<T> = RedBlackTreeSet<T, ArcTK>;
 
 impl<T> RedBlackTreeSetSync<T>
 where
@@ -167,7 +163,7 @@ where
         T: Borrow<V>,
         V: Ord,
     {
-        self.map.get_key_value(v).map(|(k, _)| k)
+        self.map.get_key_value(v).map(|(k, ())| k)
     }
 
     #[must_use]
@@ -181,12 +177,12 @@ where
 
     #[must_use]
     pub fn first(&self) -> Option<&T> {
-        self.map.first().map(|(k, _)| k)
+        self.map.first().map(|(k, ())| k)
     }
 
     #[must_use]
     pub fn last(&self) -> Option<&T> {
-        self.map.last().map(|(k, _)| k)
+        self.map.last().map(|(k, ())| k)
     }
 
     #[must_use]
@@ -211,14 +207,28 @@ where
         true
     }
 
+    /// Test whether the two sets refer to the same content in memory.
+    ///
+    /// This would return true if you’re comparing a set to itself,
+    /// or if you’re comparing a set to a fresh clone of itself.
+    pub fn ptr_eq<PO: SharedPointerKind>(&self, other: &RedBlackTreeSet<T, PO>) -> bool {
+        self.map.ptr_eq(&other.map)
+    }
+
     #[must_use]
     pub fn is_subset<PO>(&self, other: &RedBlackTreeSet<T, PO>) -> bool
     where
         PO: SharedPointerKind,
     {
+        if self.ptr_eq(other) {
+            return true;
+        }
+        if self.size() > other.size() {
+            return false;
+        }
         let mut other_it = other.iter();
 
-        for v in self.iter() {
+        for v in self {
             loop {
                 match other_it.next() {
                     Some(u) => match u.cmp(v) {
@@ -264,7 +274,7 @@ where
         Q: Ord + ?Sized,
         RB: RangeBounds<Q>,
     {
-        self.map.range(range).map(|(k, _)| k)
+        self.map.range(range).map(|(k, ())| k)
     }
 }
 
@@ -325,6 +335,22 @@ where
     }
 }
 
+impl<T: Hash, P: SharedPointerKind> Hash for RedBlackTreeSet<T, P>
+where
+    T: Ord,
+{
+    fn hash<H: Hasher>(&self, state: &mut H) {
+        // Add the hash of length so that if two collections are added one after the other it
+        // doesn't hash to the same thing as a single collection with the same elements in the same
+        // order.
+        self.size().hash(state);
+
+        for e in self {
+            e.hash(state);
+        }
+    }
+}
+
 impl<T, P> Display for RedBlackTreeSet<T, P>
 where
     T: Ord + Display,
@@ -335,7 +361,7 @@ where
 
         fmt.write_str("{")?;
 
-        for v in self.iter() {
+        for v in self {
             if !first {
                 fmt.write_str(", ")?;
             }
